@@ -5,7 +5,7 @@ from fastapi import FastAPI
 from fastapi.middleware.gzip import GZipMiddleware
 from starlette.middleware.cors import CORSMiddleware
 
-from .config import DatabaseType, Settings, StorageType, get_settings
+from .config import DatabaseType, Settings, StorageType, get_settings, AuthType
 from .exception_handlers import setup_exception_handlers
 from .exceptions import (
     BadRequestError,
@@ -13,6 +13,7 @@ from .exceptions import (
     ForbiddenError,
     HTTPException,
     NotFoundError,
+    InternalServerError,
     NotImplementedError,
     StorageError,
     UnauthorizedError,
@@ -37,7 +38,7 @@ from .utils import (
 
 __author__ = "Samuel Bradley"
 __email__ = "sam.bradley@csiro.au"
-__version__ = "1.0.2"
+__version__ = "1.1.0"
 
 
 def create_app(
