@@ -9,9 +9,11 @@ from pydantic import ValidationError
 from fa_common import (
     ForbiddenError,
     UnauthorizedError,
+    InternalServerError,
     async_get,
     force_async,
     get_settings,
+    AuthType,
 )
 from fa_common import logger as LOG
 
@@ -149,6 +151,34 @@ async def get_user(payload: dict, token: str, get_profile: bool = True) -> Optio
 
     return user
 
+async def get_standalone_user() -> AuthUser:
+    """
+    Manage user authentication and identity management using a
+    standalone licence (instead of OAuth2).
+
+    To use simply change your import for get_current_user():
+
+        if get_settings().AUTH_TYPE is AuthType.STANDALONE:
+            from fa_common.auth import get_standalone_user as get_current_user
+        else:
+            from fa_common.auth import get_current_user
+
+    returns:
+        user (AuthUser): The standalone instance user
+
+    raises:
+        InternalServerError
+    """
+    settings = get_settings()
+    if settings.AUTH_TYPE is not AuthType.STANDALONE:
+        LOG.error(f"AUTH_TYPE must be STANDALONE not {settings.AUTH_TYPE}")
+        raise InternalServerError(
+            detail="Standalone authentication not enabled",
+        )
+
+    return AuthUser(sub="standalone",
+                    name="Default User",
+                    scopes=["read:me"])
 
 async def get_current_user(
     security_scopes: SecurityScopes,
@@ -181,6 +211,6 @@ async def get_current_user(
                 )
     return user
 
-
 async def get_auth_simple(security_scopes: SecurityScopes, token: str = Depends(oauth2_scheme)) -> AuthUser:
     return await get_current_user(security_scopes, token, False)
+
