@@ -22,8 +22,13 @@ class DatabaseType(str, Enum):
     NONE = "NONE"
 
 
+class AuthType(str, Enum):
+    OAUTH2 = "OAUTH2"
+    STANDALONE = "STANDALONE"
+
+
 class Settings(BaseSettings):
-    VERSION: str = "1.0.2"
+    VERSION: str = "1.1.0"
     API_VERSION: int = 1
     API_PRE_PATH: str = f"/api/v{API_VERSION}"
 
@@ -59,6 +64,8 @@ class Settings(BaseSettings):
     ROLES_NAMESPACE: str = "http://namespace/roles"
     ENABLE_SCOPES: bool = True
 
+    AUTH_TYPE: AuthType = AuthType.OAUTH2
+
     # logging configuration
     LOGGING_LEVEL: int = logging.DEBUG if DEBUG else logging.INFO
 
