@@ -5,7 +5,7 @@ from typing import Any, List, Optional, Tuple
 
 from pydantic import Field, root_validator, validator
 
-from fa_common import CamelModel, DatabaseError, get_now
+from fa_common import CamelModel, get_now
 from fa_common import logger as LOG
 
 from .utils import get_db_client
@@ -19,7 +19,8 @@ class SortOrder(str, Enum):
 
 
 class DBIndex(CamelModel):
-    field_name: str
+    index_fields: List[Tuple[str, SortOrder]]
+    unique: bool
 
 
 class FireOffset(CamelModel):
@@ -53,6 +54,7 @@ class WhereCondition(CamelModel):
 
 class WriteResult(CamelModel):
     success: bool = True
+    new_id: Optional[str] = None
     transform_results: Optional[List[Any]]
 
 
@@ -85,15 +87,19 @@ class DocumentDBModel(CamelModel, abc.ABC):
 
     id: Optional[str] = Field(None, alias="_id")
 
-    def set_id(self) -> str:
+    @validator("id", pre=True)
+    def split_str(cls, v):
+        if isinstance(v, str):
+            return v
+        return str(v)
+
+    def set_id(self) -> Optional[str]:
         """
         If id is supplied (ex. from DB) then use it, otherwise generate new.
         """
         if not self.id:
             db = get_db_client()
             self.id = db.generate_id(self.get_db_collection())
-        if self.id is None:
-            raise DatabaseError("Failed to generate a new id for {}", __name__)
 
         return self.id
 
@@ -146,11 +152,13 @@ class DocumentDBModel(CamelModel, abc.ABC):
         )
 
     async def save(
-        self, include: set = None, exclude: set = None, rewrite_fields: dict = None,
-    ) -> str:
+        self,
+        include: set = None,
+        exclude: set = None,
+        rewrite_fields: dict = None,
+    ) -> Optional[str]:
         db = get_db_client()
-
-        _id = self.set_id()
+        # _id = self.set_id()
 
         if not rewrite_fields:
             rewrite_fields = {}
@@ -160,7 +168,10 @@ class DocumentDBModel(CamelModel, abc.ABC):
 
         insert_result = await db.insert(self, include=include, exclude=exclude)
         LOG.debug(insert_result.transform_results)
-        return _id
+        if not self.id:
+            self.id = insert_result.new_id
+
+        return self.id
 
     @classmethod
     async def update_one(cls, _id: str, data: dict) -> WriteResult:
@@ -178,7 +189,7 @@ class DocumentDBModel(CamelModel, abc.ABC):
     async def create_indexes(cls) -> Optional[List[str]]:
         if hasattr(cls, "Meta") and hasattr(cls.Meta, "indexes"):  # type:ignore
             db = get_db_client()
-            return await db.create_indexes(cls, cls.Meta.indexes)  # type:ignore
+            return await db.create_indexes(cls, cls.Meta.indexes, cls.Meta.collection)  # type:ignore
         return None
 
     class Config:
@@ -216,4 +227,5 @@ class DocumentDBTimeStampedModel(DocumentDBModel):
         """
         if v:
             return v
-        return get_now()
+        now = get_now()
+        return now.replace(microsecond=0)
